<?php
/*
Plugin : Piwishadow
Plugin URI: http://binaryworld.hd.free.fr/
*/

if (!defined('PHPWG_ROOT_PATH')) die('Hacking attempt!');

interface iModalOverlayLib {
	static public function getName();
	static public function isInstalled();
	static public function getThemes();
	public function getPlayerUrl();
	public function getFlashVarsTemplate();
	public function getDefaultLinkRelationship();
	public function appendHeaderContent($template, $tpl_var, $theme = null);
	public function getCloseThumbnailJavaScript();
}

class ShadowboxWrapper implements iModalOverlayLib {
	public static $LIB_NAME = 'shadowbox';
	
	static function getName() {
		return self::$LIB_NAME;
	}
	
	static public function isInstalled() {
		$filename = ModalOverlayLibFactory::getFactoryPath() .DS. self::getName() .DS. 'shadowbox.js';
		return file_exists($filename);
	}
	
	public function getFlashVarsTemplate() {
		return 'file={$VIDEO_URL}&image={$SRC_IMG}&controlbar.position=over';
	}
	
	public function getPlayerUrl() {
		$path = ModalOverlayLibFactory::getFactoryUrl() .'/'. self::getName() .'/player.swf';
		return $path;
	}

	public function getDefaultLinkRelationship() {
		 return 'shadowbox';
	}
	
	public function appendHeaderContent($template, $tpl_var, $theme = null) {
		$libPath = ModalOverlayLibFactory::getFactoryUrl() .'/'. self::getName(); 
		
		$scriptContent = 'var PiwishadowOverlayWnd = Shadowbox; Shadowbox.init();';
		$headContent  = '<link rel="stylesheet" type="text/css" href="'. $libPath .'/shadowbox.css">';
		$headContent .= '<script type="text/javascript" src="'. $libPath .'/shadowbox.js"></script>';
		$headContent .= '<script type="text/javascript">'. $scriptContent .'</script>';
		
		$template->append($tpl_var, $headContent);
	}
	
	public function getCloseThumbnailJavaScript() {
		return 'parent.window.Shadowbox.close(); return false;';
	}

	static public function getThemes() {
		return array();
	}
}

class MediaboxAdvancedWrapper implements iModalOverlayLib {
	public static $LIB_NAME = 'mediaboxAdvanced';

	static function getName() {
		return self::$LIB_NAME;
	}

	static public function isInstalled() {
		$filename = ModalOverlayLibFactory::getFactoryPath() .DS. self::getName() .DS. 'mediaboxAdv-1.3.4b.js';
		return file_exists($filename);
	}
	
	public function getFlashVarsTemplate() {
		return 'mediaURL={$VIDEO_URL}&teaserURL={$SRC_IMG}&allowSmoothing=true&autoPlay=false&buffer=6&showTimecode=true&loop=false&controlColor=0xFFFFFF&controlBackColor=0x000000&scaleIfFullScreen=true&showScalingButton=true&defaultVolume=100&crop=false';
	}
	
	public function getPlayerUrl() {
		$path = ModalOverlayLibFactory::getFactoryUrl() .'/'. self::getName() .'/NonverBlaster.swf';
		return $path;
	}
	
	public function getDefaultLinkRelationship() {
		return 'lightbox';
	}
	
	public function appendHeaderContent($template, $tpl_var, $theme = null) {
		$libPath = ModalOverlayLibFactory::getFactoryUrl() .'/'. self::getName(); 
		$content = '';
		
		if (!empty($theme)) {
			$content .= '<link rel="stylesheet" href="'. $libPath .'/themes/'. $theme .'/style.css" type="text/css" media="screen" />';
		}

		$content .= '<script src="'. $libPath .'/mootools-1.2.5-core-yc.js" type="text/javascript"></script>';
		$content .= '<script src="'. $libPath .'/Quickie.js" type="text/javascript"></script>';
		$content .= '<script type="text/javascript">var mediaboxAdvancedPath = "'. $libPath .'"</script>';
		$content .= '<script src="'. $libPath .'/mediaboxAdv-1.3.4b.js" type="text/javascript"></script>';
		$content .= '<script type="text/javascript">var PiwishadowOverlayWnd = Mediabox;</script>';
		
		$template->append($tpl_var, $content);
	}

	public function getCloseThumbnailJavaScript() {
		return 'parent.window.Shadowbox.close(); return false;';
	}
	
	static public function getThemes() {
		return ModalOverlayLibFactory::getDirectoriesFromPath(ModalOverlayLibFactory::getFactoryPath() .DS. self::getName() .DS. 'themes');
	}
}


class ModalOverlayLibFactory {
	
	
	public static function getFactoryPath() {
		return dirname(__FILE__);
	}
	
	public static function getFactoryUrl() {
		return get_root_url() .'plugins/'. basename(dirname(__FILE__));
	}
	
	public static function getInstalledOverlayLibs() {
		$libs = array();
		if (MediaboxAdvancedWrapper::isInstalled() === true) $libs[] =  MediaboxAdvancedWrapper::getName();
		if (ShadowboxWrapper::isInstalled() === true) $libs[] =  ShadowboxWrapper::getName();
		return $libs;
	}
	
	public static function getDefaultOverlayLib() {
		return MediaboxAdvancedWrapper::getName();
	}
	
	public static function getDefaultOverlayTheme()	{
		$themes = MediaboxAdvancedWrapper::getThemes();
		return (empty($themes)) ? null : $themes[0];
	}
	
	public static function createModalOverlayLib($libName) {
		if (0 === strcmp($libName, MediaboxAdvancedWrapper::getName())) {
			return new MediaboxAdvancedWrapper();
		} else if (0 === strcmp($libName, ShadowboxWrapper::getName())) {
			return new ShadowboxWrapper();
		}
		return null;
	}
	
	public static function getDirectoriesFromPath($path) {
		static $weeds = array('.', '..');
		$directories = array_diff(scandir($path), $weeds);
		$dirs = array(); 
		foreach($directories as $value) {
			if(is_dir($path .DS. $value)) {
				$dirs[] = $value;
			}
		}
		return $dirs;
	}
}

?>